#!/usr/bin/env python
# -*- coding: utf-8 -*-

# author: Pocholo
# date: 6/12/23

# Comments directed to http://gimpchat.com

# Inspired by Tim Tran script "Map Fold and Tom Bland video tutorial".

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

import math
from gimpfu import *

def pm_three_or_four_fold_brochure_effect(img, layer, fold, y_magnitud):

    #Undo group start
    pdb.gimp_image_undo_group_start(img)
        
    if fold==0:
        pdb.gimp_message_set_handler(0)
        pdb.gimp_message("Pick a Fold\nOn The Fold Selection")
    
    if fold==1:    
        layerlist = img.layers
        for layer in layerlist:
            if not layer.has_alpha:
                pdb.gimp_layer_add_alpha(layer)
        
        width = pdb.gimp_image_width(img)
        height = pdb.gimp_image_height(img)
        y_shear = (height * y_magnitud) / 100
        
        #Doubled the size of the canvas 
        pdb.gimp_image_resize(img, width *2, height *2, width /2, height /2)
        pdb.gimp_layer_resize_to_image_size(layer)
        
        #First fold
        pdb.gimp_image_select_rectangle(img, 2, width /2, height /2, width /3, height)
        layer1 = pdb.gimp_item_transform_shear(layer, ORIENTATION_VERTICAL, 0 - y_shear)
        
        #Second fold
        pdb.gimp_image_select_rectangle(img, 2,  width /2 + width /3, height /2, width /3, height)
        layer2 = pdb.gimp_item_transform_shear(layer, ORIENTATION_VERTICAL, y_shear)

        #Third fold
        pdb.gimp_image_select_rectangle(img, 2,  width /2 + width /3 *2, height /2, width /3+1, height)
        sheared_layer = pdb.gimp_item_transform_shear(layer, ORIENTATION_VERTICAL, 0 - y_shear)
        pdb.gimp_floating_sel_anchor(sheared_layer)
            
        #Create a fold shadow effect
        pdb.gimp_image_select_rectangle(img, 2, width /2, 0, width /3, height *2)
        pdb.gimp_brightness_contrast(layer, -50, 0)
        pdb.gimp_image_select_rectangle(img, 2,  width /2 + width /3  *2, 0, width /3, height *2)
        pdb.gimp_brightness_contrast(layer, -50, 0)
        pdb.gimp_selection_none(img)
                
        #Create a shadow
        pdb.script_fu_perspective_shadow(img, layer, 
	                                             90,  #angle
												5.0,  #relative dist from horizon
											    0.6,  #relative length fron shadow
												 25,  #blur radius
											"black",  #color
											     80,  #opacity
												  1,  #interpolation
											  FALSE)  #allow resizing
        

######################## Four fold option #############################################################################  
    
    if fold==2:
        layerlist = img.layers
        for layer in layerlist:
            if not layer.has_alpha:
                pdb.gimp_layer_add_alpha(layer)
        
        width = pdb.gimp_image_width(img)
        height = pdb.gimp_image_height(img)
        y_shear = (height * y_magnitud) / 100
        
        #Doubled the size of the canvas
        pdb.gimp_image_resize(img, width *2, height *2, width /2, height /2)
        pdb.gimp_layer_resize_to_image_size(layer)
        
        #First fold
        pdb.gimp_image_select_rectangle(img, 2, width /2, height /2, width /4, height)
        layer1 = pdb.gimp_item_transform_shear(layer, ORIENTATION_VERTICAL, 0 - y_shear)
          
        #Second fold
        pdb.gimp_image_select_rectangle(img, 2,  width /2 + width /4, height /2, width /4, height)
        layer2 = pdb.gimp_item_transform_shear(layer, ORIENTATION_VERTICAL, y_shear)
          
        #Third fold
        pdb.gimp_image_select_rectangle(img, 2,  width /2 + width /4  *2, height /2, width /4, height)
        layer3 = pdb.gimp_item_transform_shear(layer, ORIENTATION_VERTICAL, 0 - y_shear)
       
        #Fourth fold
        pdb.gimp_image_select_rectangle(img, 2,  width /2 + width /4 * 3, height /2, width /4, height)
        sheared_layer = pdb.gimp_item_transform_shear(layer, ORIENTATION_VERTICAL, y_shear)
        pdb.gimp_floating_sel_anchor(sheared_layer)
        
        #Create a fold shadow effect
        pdb.gimp_image_select_rectangle(img, 2, width /2 + width /4, 0, width /4, height *2)
        pdb.gimp_brightness_contrast(layer, -50, 0)
        pdb.gimp_image_select_rectangle(img, 2,  width /2 + width /4  *3, 0, width /4, height *2)
        pdb.gimp_brightness_contrast(layer, -50, 0)
        pdb.gimp_selection_none(img)
        
        #Create a shadow
        pdb.script_fu_perspective_shadow(img, layer, 
	                                             90,  #angle
												5.0,  #relative dist from horizon
											    0.6,  #relative length fron shadow
												 25,  #blur radius
											"black",  #color
											     80,  #opacity
												  1,  #interpolation
											  FALSE)  #allow resizing
    
    
    pdb.gimp_displays_flush()  

	#Undo group end
    pdb.gimp_image_undo_group_end(img)
	
register(
    "pm_three_or_four_fold_brochure_effect",
    "Create a map fold",
    "Create a map fold",
    "Pocholo",
    "Pocholo",
    "2023",
    "Create a Three or Four Fold Brochure Effect",
    "",
    [	
    (PF_IMAGE,    "img", "Source image", None),
    (PF_DRAWABLE, "layer", "Source layer", None),
    (PF_OPTION,  "fold", "Fold Selection:", 0 ,["Pick a Fold", "3", "4"]),
    (PF_SPINNER,  "y_magnitud", "Shear Magnitude", 15, (5, 45, 1)),   
    ],
    [],
    pm_three_or_four_fold_brochure_effect, menu="<Image>/Python-Fu/Special Effects/"),   
main()	